import { getApp } from '@genesislcap/foundation-shell/app';
import { neutralLayer2 } from '@microsoft/fast-components';
import { css } from '@microsoft/fast-element';
import { backgroundNavOption, ColorHEX, defaultBackgroundHover, defaultBackgroundItem, PrimaryRapidColorHEX, } from '../styles/colors';
/**
 * Base styles for the foundation-header
 *
 * @returns ElementStyles instance for the foundation-header
 *
 * @public
 */
export const MainStyles = css `
  :host {
    display: flex;
    flex-direction: row;

    --primary-gradient-angle: -113.5deg;
    --design-unit: 2.5;
  }

  zero-design-system-provider,
  .dynamic-template {
    width: 100%;
  }

  .nav-listbox {
    background: ${neutralLayer2};
    display: flex;
    flex: 1;
    flex-direction: row;
    align-items: center;
    justify-content: space-between;
    box-shadow: 0 0 15px 0 rgb(0 0 0 / 30%);
  }

  fast-listbox {
    border-color: var(--rapid-ag-background-color);
  }

  .nav-leftside {
    background: ${neutralLayer2};
    flex: 1;
    flex-direction: row;
    align-items: center;
    margin-left: calc(var(--design-unit) * 6px);
    display: flex;
  }

  .nav-leftside:focus-within {
    box-shadow: none;
  }

  ::slotted(fast-option),
  .nav-listbox fast-option {
    margin: 0 calc(var(--design-unit) * 2px);
    padding: 0 calc(var(--design-unit) * 6px);

    --focus-stroke-width: 0;
  }

  ::slotted(fast-option.selected),
  .nav-listbox fast-option.selected {
    background: ${backgroundNavOption};
    color: ${ColorHEX.white};
  }

  ::slotted(fast-option:not(.selected)),
  .nav-listbox fast-option:not(.selected) {
    background-color: ${defaultBackgroundItem};
    color: #c9c9c9;
  }

  ::slotted(fast-option:not(.selected):hover),
  .nav-listbox fast-option:not(.selected):hover {
    background-color: ${defaultBackgroundHover};
    color: ${ColorHEX.white};
  }

  .top-layout zero-icon {
    position: absolute;
    right: calc(var(--design-unit) * 6px);
    top: 50%;
    transform: translateY(-50%);
    font-size: 25px;
    opacity: 80%;
    cursor: pointer;
  }

  .logout-container zero-icon {
    padding: 0 calc(var(--design-unit) * 3px);
  }

  .nav-listbox .bars-container {
    margin-right: calc(var(--design-unit) * 3px);
  }

  .user-container zero-icon {
    font-size: 20px;
    margin-right: calc(var(--design-unit) * 2px);
    color: #879ba6;
  }

  .group-container zero-icon {
    padding-right: 10px;
    color: #879ba6;
  }

  .nav-listbox .bars-container zero-icon {
    cursor: pointer;
    font-size: calc(var(--design-unit) * 8px);
    background:
      linear-gradient(
          var(--primary-gradient-angle),
          ${PrimaryRapidColorHEX.blue} 0%,
          ${PrimaryRapidColorHEX.purple} 100%
        )
        top/100% 1px,
      linear-gradient(
          var(--primary-gradient-angle),
          ${PrimaryRapidColorHEX.blue} 0%,
          ${PrimaryRapidColorHEX.purple} 100%
        )
        bottom/100% 1px;
    /* stylelint-disable-next-line property-no-vendor-prefix */
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
  }

  .logo-container {
    display: flex;
    align-items: center;
    margin-right: calc(var(--design-unit) * 3px);
  }

  .logo {
    height: calc(var(--design-unit) * 8px);
    width: calc(var(--design-unit) * 10px);
  }

  .nav-rightside {
    display: flex;
    flex: 1;
    flex-direction: row;
    align-items: center;
    justify-content: flex-end;
    margin-right: calc(var(--design-unit) * 6px);
    color: #c9c9c9;
  }

  .user-container {
    background-color: ${defaultBackgroundItem};
    padding: calc(var(--design-unit) * 1px);
    font-size: 14px;
    display: flex;
    align-items: center;
    border-radius: calc(var(--control-corner-radius) * 1px);
    cursor: pointer;
  }

  .icon-container {
    font-size: 20px;
    padding: calc(var(--design-unit) * 3px);
    margin-right: calc(var(--design-unit) * 4px);
    color: #879ba6;
    cursor: pointer;
  }

  .connection-indicator-container {
    margin-right: calc(var(--design-unit) * 4px);
  }

  .open-nav {
    width: 300px;
  }

  .top-layout {
    background:
      linear-gradient(
          var(--primary-gradient-angle),
          ${PrimaryRapidColorHEX.blue} 0%,
          ${PrimaryRapidColorHEX.purple} 100%
        )
        top/100% 1px,
      linear-gradient(
          var(--primary-gradient-angle),
          ${PrimaryRapidColorHEX.blue} 0%,
          ${PrimaryRapidColorHEX.purple} 100%
        )
        bottom/100% 1px;
    background-origin: border-box;
    background-size: cover;
    background-repeat: no-repeat;
    width: 100%;
    height: 15%;
    max-height: 120px;
    display: flex;
    flex-direction: row;
    align-items: center;
    position: relative;
  }

  .top-layout img {
    width: 50px;
    margin-left: calc(var(--design-unit) * 6px);
  }

  .top-layout zero-icon:hover {
    opacity: 100%;
  }

  .group-container {
    height: 100%;
    display: flex;
    flex-direction: column;
  }

  ::slotted(zero-tree-view) {
    --type-ramp-base-font-size: 12px;
  }

  ::slotted(div) {
    color: ${PrimaryRapidColorHEX.blue};
    font-size: var(--type-ramp-minus-1-font-size);
    margin-bottom: calc(var(--design-unit) * 4px);
    padding-left: calc(var(--design-unit) * 4px);
    padding-right: calc(var(--design-unit) * 4px);
  }

  .nav-preferences {
    width: 100%;
    height: 25%;
    max-height: 250px;
    display: flex;
    flex-direction: column;
    justify-content: flex-start;
  }

  .logout-container {
    align-items: center;
    background-color: var(--neutral-fill-rest);
    border: calc(var(--stroke-width) * 1px) solid ${defaultBackgroundItem};
    cursor: pointer;
    display: flex;
    flex-direction: row;
    height: 8%;
    max-height: 80px;
    padding: 3%;
  }

  .logout-container:hover {
    background-color: var(--neutral-fill-hover);
  }

  .language-selector {
    min-width: 80px;
    width: 80px;
  }

  .language-selector:hover,
  .language-selector:active,
  .language-selector:visited,
  .language-selector:focus-within {
    border-color: #333;
  }
`.withBehaviors(getApp().registerStylesTarget('header'));
